@@ -37,8 +37,20 @@ class ResizeNodeCountRequest(RpcRequest):
 	def set_ClusterId(self,ClusterId):
 		self.add_query_param('ClusterId',ClusterId)
 
+	def get_VSwitchId(self):
+		return self.get_query_params().get('VSwitchId')
+
+	def set_VSwitchId(self,VSwitchId):
+		self.add_query_param('VSwitchId',VSwitchId)
+
 	def get_NodeCount(self):
 		return self.get_query_params().get('NodeCount')
 
 	def set_NodeCount(self,NodeCount):
-		self.add_query_param('NodeCount',NodeCount)
\ No newline at end of file
+		self.add_query_param('NodeCount',NodeCount)
+
+	def get_ZoneId(self):
+		return self.get_query_params().get('ZoneId')
+
+	def set_ZoneId(self,ZoneId):
+		self.add_query_param('ZoneId',ZoneId)
\ No newline at end of file
